## Prerequisites

- Python3

## Setting up a development environment
- Fork the repository to your own account and clone the repository from github with git clone command. 
- install all dependencies using `make develop`.  

## Making changes

- Please make changes with descriptive commit messages and create tests for new codes you created. 
- Lint and autoformat your code using 'make lint' and 'make format'.
- Open PR back to the main repo on Github.

# Contribution Guidelines

Create a PR to the main and write down what you changed and how it works in the comment section.